@@ -293,33 +293,54 @@ function whp_TestConnection(array $params) {
     try {
         $serverdata = $params['serverdata'];
         
+        // Add detailed logging for debugging
+        logModuleCall('whp', 'TestConnection', array(
+            'hostname' => $serverdata['hostname'],
+            'port' => $serverdata['port'],
+            'secure' => $serverdata['secure'],
+            'username' => !empty($serverdata['username']) ? 'set' : 'empty',
+            'password' => !empty($serverdata['password']) ? 'set' : 'empty'
+        ), 'Starting connection test');
+        
         $response = whp_api_call($serverdata, 'GET', 'system.php?action=health');
         
-        if ($response['status'] === 'success') {
-            $health = $response['data'];
-            if ($health['status'] === 'healthy') {
-                return array(
-                    'success' => true,
-                    'message' => 'Connection successful - Server is healthy',
-                );
+        if (is_array($response) && isset($response['status'])) {
+            if ($response['status'] === 'success') {
+                $health = $response['data'] ?? array();
+                $status = $health['status'] ?? 'unknown';
+                
+                if ($status === 'healthy') {
+                    return array(
+                        'success' => true,
+                        'message' => 'Connection successful - Server is healthy',
+                    );
+                } else {
+                    return array(
+                        'success' => true,
+                        'message' => 'Connection successful - Server status: ' . $status,
+                    );
+                }
             } else {
+                $message = $response['message'] ?? 'Unknown API error';
                 return array(
-                    'success' => true,
-                    'message' => 'Connection successful - Server status: ' . $health['status'],
+                    'success' => false,
+                    'message' => 'API Error: ' . $message,
                 );
             }
         } else {
             return array(
                 'success' => false,
-                'message' => 'Connection failed: ' . $response['message'],
+                'message' => 'Invalid response format from server',
             );
         }
         
     } catch (Exception $e) {
-        logModuleCall('whp', __FUNCTION__, $params, $e->getMessage());
+        $errorMsg = $e->getMessage();
+        logModuleCall('whp', 'TestConnection', $params, 'Exception: ' . $errorMsg);
+        
         return array(
             'success' => false,
-            'message' => 'Connection test failed: ' . $e->getMessage(),
+            'message' => 'Connection test failed: ' . $errorMsg,
         );
     }
 }
@@ -467,7 +488,7 @@ function whp_AdminServicesTabFields(array $params) {
  */
 function whp_api_call($serverdata, $method, $endpoint, $data = null) {
     $hostname = $serverdata['hostname'];
-    $port = $serverdata['secure'] ? $serverdata['port'] ?: 443 : $serverdata['port'] ?: 80;
+    $port = $serverdata['secure'] ? ($serverdata['port'] ?: 443) : ($serverdata['port'] ?: 80);
     $protocol = $serverdata['secure'] ? 'https' : 'http';
     
     // Server authentication details
